

set -ex



test -L $PREFIX/lib/libcufft.so.11
test -L $PREFIX/lib/libcufftw.so.11
test -L $PREFIX/lib/libcufft.so.11.2.6.28
test -L $PREFIX/lib/libcufftw.so.11.2.6.28
test -L $PREFIX/targets/sbsa-linux/lib/libcufft.so.11
test -L $PREFIX/targets/sbsa-linux/lib/libcufftw.so.11
test -f $PREFIX/targets/sbsa-linux/lib/libcufft.so.11.2.6.28
test -f $PREFIX/targets/sbsa-linux/lib/libcufftw.so.11.2.6.28
exit 0
